@@ -4,7 +4,6 @@ correls <- function(y, x, type = "pearson", a = 0.05, rho = 0) {
   ## type supported is either "pearson" or "spearman"
   ## a is the significance level
   ## rho is the hypothesised correlation
-
   n <- length(y)
 
   if (type == "pearson") {
@@ -21,7 +20,7 @@ correls <- function(y, x, type = "pearson", a = 0.05, rho = 0) {
   }
 
   test <- (zh1 - zh0) / se ## test statistic
-  pvalue <-  2 * ( pt( -abs(test), n - 3 ) )  ## p-value
+  pvalue <-  2 * pt( abs(test), n - 3, lower.tail = FALSE )  ## p-value
   b1 <- zh1 - qt(1 - a/2, n - 3) * se
   b2 <- zh1 + qt(1 - a/2, n - 3) * se
   ca <- cbind(b1 ,b2)
