@@ -46,15 +46,7 @@ NumericMatrix sort_row(NumericMatrix x,const bool descend){
 
 //[[Rcpp::export]]
 NumericMatrix sort_mat(NumericMatrix x,const bool descend,const bool by_row){
-	switch(by_row){
-		case true:{
-			return sort_row(x,descend);
-		}
-		default:{
-			return sort_col(x,descend);
-		}
-	}
-	stop("Error in sort matrix.\n");
+	return by_row ? sort_row(x,descend) : sort_col(x,descend);
 }
 
 // sort_mat
