@@ -47,15 +47,7 @@ NumericMatrix stable_sort_row(NumericMatrix x,const bool descend){
 
 //[[Rcpp::export]]
 NumericMatrix stable_sort_mat(NumericMatrix x,const bool descend,const bool by_row){
-	switch(by_row){
-		case true:{
-			return stable_sort_row(x,descend);
-		}
-		default:{
-			return stable_sort_col(x,descend);
-		}
-	}
-	stop("Error in sort matrix.\n");
+	return by_row ? stable_sort_row(x,descend) : stable_sort_col(x,descend);
 }
 
 // sort_mat
